local fs = require "nixio.fs"

m = Map("dlms-to-mqtt", translate("DLMS to MQTT"))

section_global = m:section(TypedSection, "global", translate("Enable/ Disable"))
section_global.anonymous = false
section_global.addremove = false
section_global.name = "global"

option_enabled = section_global:option(Flag, "enabled", translate("Enabled"),
    translate("Enable DLMS to MQTT"))
option_enabled.rmempty = false
option_enabled.default = "1"

s = m:section(TypedSection, "mqtt", translate("DLMS MQTT"), "")
s.anonymous = true
s.addremove = false

-- MQTT Section
----------------------
section_mqtt = m:section(TypedSection, "mqtt", translate("DLMS to MQTT IoT Configuration"))
section_mqtt.anonymous = true
section_mqtt.addremove = false

mqtt_host = section_mqtt:option(Value, "host", translate("MQTT Server"), translate("MQTT Server IP address/ host name"))
mqtt_host.datatype = "host"
mqtt_host.default = "192.168.1.254"

mqtt_port = section_mqtt:option(Value, "port", translate("Port"))
mqtt_port.default = "1883"
mqtt_port.datatype = "port"

mqtt_username = section_mqtt:option(Value, "username", translate("Username"))

mqtt_password = section_mqtt:option(Value, "password", translate("Password"))
mqtt_password.password = true

mqtt_topic = section_mqtt:option(Value, "data_topic", translate("Topic"), translate("Topic to send DLMS Data"))

clean_session = section_mqtt:option(Flag, "clean_session", translate("Clean Session"),
    translate("Clean session on reconnect by discaring any messages."))
clean_session.default = "0"
clean_session.rmempty = false

qos = s:option(Value, "qos", "QoS (Quality Of Service)")
qos.datatype = "range(0,2)"

retain = s:option(ListValue, "retain", "Retain", translate("Makes the message retained."))
retain:value("1", translate("Yes"))
retain:value("0", translate("No"))
retain.default = "0"

client_id = section_mqtt:option(Value, "client_id", translate("Client Id"))

will_topic = section_mqtt:option(Value, "will_topic", translate("Will Topic"))

will_payload = section_mqtt:option(Value, "will_payload", translate("Will Payload"))

will_qos = section_mqtt:option(Value, "will_qos", translate("Will QoC"))
will_qos.datatype = "uinteger"
will_qos.max = 3

will_retain = section_mqtt:option(Flag, "will_retain", translate("Will Retain"))
will_retain.default = "0"
will_retain.rmempty = false

reconnect_delay = section_mqtt:option(Value, "reconnect_delay", translate("Reconnection Delay"))
reconnect_delay.datatype = "uinteger"

reconnect_exponential_backoff = section_mqtt:option(Flag, "reconnect_exponential_backoff", translate("Reconnect Exponential Backoff"))
reconnect_exponential_backoff.default = "0"
reconnect_exponential_backoff.rmempty = false

reconnect_delay_max = section_mqtt:option(Value, "reconnect_delay_max", translate("Maximum Reconnection Delay"))
reconnect_delay_max.datatype = "uinteger"
reconnect_delay_max:depends("reconnect_exponential_backoff", "1")

max_inflight_messages = section_mqtt:option(Value, "max_inflight_messages", translate("Maximum In-flight messages"))
max_inflight_messages.datatype = "uinteger"

return m
